@@ -20,10 +20,6 @@ def watcher_defaults():
         'uid': None,
         'gid': None,
         'send_hup': False,
-        'check_flapping': True,
-        'flapping_attempts': 2,
-        'flapping_window': 1,
-        'retry_in': 7,
         'max_retry': 5,
         'graceful_timeout': 30,
         'rlimits': dict(),
@@ -101,6 +97,12 @@ def stream_config(watcher_name, stream_conf):
 
 
 def get_config(config_file):
+    if not os.path.exists(config_file):
+        sys.stderr.write("the configuration file %r does not exist\n" %
+                config_file)
+        sys.stderr.write("Exiting...\n")
+        sys.exit(1)
+
     cfg, cfg_files_read = read_config(config_file)
     dget = cfg.dget
     config = {}
@@ -111,8 +113,6 @@ def get_config(config_file):
     config['pubsub_endpoint'] = dget('circus', 'pubsub_endpoint',
                                      'tcp://127.0.0.1:5556')
     config['stats_endpoint'] = dget('circus', 'stats_endpoint', None, str)
-    config['check_flapping'] = dget('circus', 'check_flapping', True, bool)
-
     stream_backend = dget('circus', 'stream_backend', 'thread')
 
     if stream_backend == 'gevent':
@@ -132,9 +132,14 @@ def get_config(config_file):
 
     config['stream_backend'] = stream_backend
 
-    # Initialize watchers to manage
+    # Initialize watchers & plugins to manage
     watchers = []
+    plugins = []
+
     for section in cfg.sections():
+        if section.startswith("plugin:"):
+            plugins.append(dict(cfg.items(section)))
+
         if section.startswith("watcher:"):
             watcher = watcher_defaults()
             watcher['name'] = section.split("watcher:", 1)[1]
@@ -168,16 +173,6 @@ def get_config(config_file):
                 elif opt == 'check_flapping':
                     watcher['check_flapping'] = dget(section, 'check_flapping',
                                                      True, bool)
-                elif opt == 'flapping_attempts':
-                    watcher['flapping_attempts'] = dget(section,
-                                                        "flapping_attempts", 2,
-                                                        int)
-                elif opt == 'flapping_window':
-                    watcher['flapping_window'] = dget(section,
-                                                      "flapping_window", 1,
-                                                      int)
-                elif opt == 'retry_in':
-                    watcher['retry_in'] = dget(section, "retry_in", 7, int)
                 elif opt == 'max_retry':
                     watcher['max_retry'] = dget(section, "max_retry", 5, int)
                 elif opt == 'graceful_timout':
@@ -192,6 +187,9 @@ def get_config(config_file):
                     watcher['rlimits'][limit] = int(val)
                 elif opt == 'priority':
                     watcher['priority'] = dget(section, "priority", 0, int)
+                else:
+                    # freeform
+                    watcher[opt] = val
 
             # second pass, parse stream conf
             stdout_conf = watcher.get('stdout_stream', {})
@@ -208,4 +206,5 @@ def get_config(config_file):
             watchers.append(watcher)
 
     config['watchers'] = watchers
+    config['plugins'] = plugins
     return config
