@@ -13,6 +13,9 @@ if PY3:
     def s2b(s):     # NOQA
         return s.encode('latin1')
 
+    def bytestring(s): # NOQA
+        return s
+
     import io
     StringIO = io.StringIO      # NOQA
     BytesIO = io.BytesIO        # NOQA
@@ -32,6 +35,11 @@ else:
     def s2b(s):     # NOQA
         return s
 
+    def bytestring(s): # NOQA
+        if isinstance(s, unicode):
+            return s.encode('utf-8')
+        return s
+
     try:
         import cStringIO
         StringIO = cStringIO.StringIO   # NOQA
