@@ -5,6 +5,7 @@ import time
 
 from circus.client import CallError, CircusClient, make_message
 from circus.tests.support import TestCircus
+from circus.plugins import CircusPlugin
 
 
 class DummyProcess(object):
@@ -42,6 +43,18 @@ def run_dummy(test_file):
     return 1
 
 
+class Plugin(CircusPlugin):
+    name = 'dummy'
+
+    def handle_recv(self, data):
+        topic, msg = data
+        topic_parts = topic.split(".")
+        watcher = topic_parts[1]
+        action = topic_parts[2]
+        with open(self.config['file'], 'a+') as f:
+            f.write('%s:%s\n' % (watcher, action))
+
+
 class DummyProcess1(object):
 
     def __init__(self):
@@ -256,3 +269,52 @@ class TestTrainer(TestCircus):
 
         resp = self.cli.call(make_message("status", name="test"))
         self.assertEqual(resp.get('status'), "active")
+
+    def test_plugins(self):
+        # killing the setUp runner
+        self._stop_runners()
+        self.cli.stop()
+
+        fd, datafile = mkstemp()
+        os.close(fd)
+
+        # setting up a circusd with a plugin
+        dummy_process = 'circus.tests.test_arbiter.run_dummy'
+        plugin = 'circus.tests.test_arbiter.Plugin'
+        plugins = [{'use': plugin, 'file': datafile}]
+        self._run_circus(dummy_process, plugins=plugins)
+
+        # doing a few operations
+        cli = CircusClient()
+        msg1 = make_message("list", name="test")
+        resp = cli.call(msg1)
+        self.assertEqual(resp.get('processes'), [1])
+        msg2 = make_message("incr", name="test")
+        cli.call(msg2)
+        resp = cli.call(msg1)
+        self.assertEqual(resp.get('processes'), [1, 2])
+        cli.call(msg2)
+        resp = cli.call(msg1)
+        self.assertEqual(resp.get('processes'), [1, 2, 3])
+
+        # wait a bit
+        time.sleep(.2)
+
+        # checking what the plugin did
+        with open(datafile) as f:
+            data = [line for line in f.read().split('\n')
+                    if line != '']
+
+        wanted = ['test:spawn', 'test:spawn']
+        self.assertEqual(data, wanted)
+
+    def test_singleton(self):
+        self._stop_runners()
+
+        dummy_process = 'circus.tests.test_arbiter.run_dummy'
+        self._run_circus(dummy_process, singleton=True)
+        cli = CircusClient()
+
+        # adding more than one process should fail
+        res = cli.send_message('incr', name='test')
+        self.assertEqual(res['numprocesses'], 1)
