@@ -1,3 +1,4 @@
+import logging
 from datetime import timedelta
 import grp
 import os
@@ -56,6 +57,21 @@ except ImportError:
         return
 
 
+MAXFD = 1024
+if hasattr(os, "devnull"):
+    REDIRECT_TO = os.devnull
+else:
+    REDIRECT_TO = "/dev/null"
+
+LOG_LEVELS = {
+    "critical": logging.CRITICAL,
+    "error": logging.ERROR,
+    "warning": logging.WARNING,
+    "info": logging.INFO,
+    "debug": logging.DEBUG}
+
+LOG_FMT = r"%(asctime)s [%(process)d] [%(levelname)s] %(message)s"
+LOG_DATE_FMT = r"%Y-%m-%d %H:%M:%S"
 _SYMBOLS = ('K', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y')
 
 
@@ -94,7 +110,7 @@ def bytes2human(n):
 _PROCS = {}
 
 
-def get_info(process=None, interval=0):
+def get_info(process=None, interval=0, with_childs=False):
     """Return information about a process. (can be an pid or a Process object)
 
     If process is None, will return the information about the current process.
@@ -164,13 +180,17 @@ def get_info(process=None, interval=0):
     info['cmdline'] = cmdline
 
     info['children'] = []
-    for child in process.get_children():
-        info['children'].append(get_info(child, interval=interval))
+    if with_childs:
+        for child in process.get_children():
+            info['children'].append(get_info(child, interval=interval))
 
     return info
 
 
 def to_bool(s):
+    if isinstance(s, bool):
+        return s
+
     if s.lower().strip() in ("true", "1",):
         return True
     elif s.lower().strip() in ("false", "0"):
